@@ -1,4 +1,5 @@
-from .app import App
+from botty_core import App
+
 from .config import BOT_TOKEN
 
 app = App(BOT_TOKEN)
