@@ -4,7 +4,7 @@ from telegram.constants import ParseMode
 from telegram.ext import Application, Defaults
 from telegram.warnings import PTBUserWarning
 
-from .handlers import CompositeHandler
+from .types import PTBHandler
 
 warnings.filterwarnings(
     action="ignore",
@@ -31,7 +31,6 @@ class App:
         builder.concurrent_updates(True)  # noqa: FBT003
         self.raw = builder.build()
 
-    def run(self, handler: CompositeHandler) -> None:
-        for subhandler in handler.build():
-            self.raw.add_handler(subhandler)
+    def run(self, handler: PTBHandler) -> None:
+        self.raw.add_handler(handler)
         self.raw.run_polling()
