@@ -1,3 +1,4 @@
+from collections.abc import Awaitable, Callable
 from typing import TypeVar
 
 import telegram
@@ -42,3 +43,7 @@ class ContextFieldError(AttributeError):
 
     def __str__(self) -> str:
         return f"No `{self.field}` for {self.context}"
+
+
+ContextT = TypeVar("ContextT", bound=Context)
+Callback = Callable[[ContextT], Awaitable[None]]
